/*
 * This file was generated by orbit-idl-2 - DO NOT EDIT!
 */

#include <string.h>
#define ORBIT2_STUBS_API
#define ORBIT_IDL_C_COMMON
#define evolution_calendar_COMMON
#include "evolution-calendar.h"

static const CORBA_unsigned_long ORBit_zero_int = 0;

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalView_start(POA_GNOME_Evolution_Calendar_CalView             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_start)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_start (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded(POA_GNOME_Evolution_Calendar_CalViewListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectsAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev)) {
_impl_notifyObjectsAdded (_o_servant, (const CORBA_sequence_CORBA_string*)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified(POA_GNOME_Evolution_Calendar_CalViewListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectsModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev)) {
_impl_notifyObjectsModified (_o_servant, (const CORBA_sequence_CORBA_string*)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved(POA_GNOME_Evolution_Calendar_CalViewListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectsRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalObjIDSeq* ids, CORBA_Environment *ev)) {
_impl_notifyObjectsRemoved (_o_servant, (const CORBA_sequence_GNOME_Evolution_Calendar_CalObjID*)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress(POA_GNOME_Evolution_Calendar_CalViewListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyQueryProgress)(PortableServer_Servant _servant, const CORBA_char * message, const CORBA_short percent, CORBA_Environment *ev)) {
_impl_notifyQueryProgress (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_short *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone(POA_GNOME_Evolution_Calendar_CalViewListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyQueryDone)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyQueryDone (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal__get_uri(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
CORBA_string (*_impl__get_uri)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
*(CORBA_string *)_o_retval = _impl__get_uri (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_open(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_open)(PortableServer_Servant _servant, const CORBA_boolean only_if_exists, const CORBA_char * username, const CORBA_char * password, CORBA_Environment *ev)) {
_impl_open (_o_servant, *(const CORBA_boolean *)_o_args[0], *(const CORBA_char * *)_o_args[1], *(const CORBA_char * *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_remove(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_remove)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_remove (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_isReadOnly(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_isReadOnly)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_isReadOnly (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getStaticCapabilities(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getStaticCapabilities)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_getStaticCapabilities (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getCalAddress(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getCalAddress)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_getCalAddress (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getAlarmEmailAddress(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getAlarmEmailAddress)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_getAlarmEmailAddress (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getLdapAttribute(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getLdapAttribute)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_getLdapAttribute (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_setMode(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_setMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev)) {
_impl_setMode (_o_servant, *(const CORBA_long *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getDefaultObject(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getDefaultObject)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_getDefaultObject (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getObject(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev)) {
_impl_getObject (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getObjectList(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getObjectList)(PortableServer_Servant _servant, const CORBA_char * query, CORBA_Environment *ev)) {
_impl_getObjectList (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getTimezone(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getTimezone)(PortableServer_Servant _servant, const CORBA_char * tzid, CORBA_Environment *ev)) {
_impl_getTimezone (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_addTimezone(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_addTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev)) {
_impl_addTimezone (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_setDefaultTimezone(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_setDefaultTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev)) {
_impl_setDefaultTimezone (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getChanges(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getChanges)(PortableServer_Servant _servant, const CORBA_char * change_id, CORBA_Environment *ev)) {
_impl_getChanges (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getFreeBusy(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_UserList* users, const GNOME_Evolution_Calendar_Time_t start, const GNOME_Evolution_Calendar_Time_t end, CORBA_Environment *ev)) {
_impl_getFreeBusy (_o_servant, (const CORBA_sequence_GNOME_Evolution_Calendar_User*)_o_args[0], *(const CORBA_unsigned_long *)_o_args[1], *(const CORBA_unsigned_long *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_discardAlarm(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_discardAlarm)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * auid, CORBA_Environment *ev)) {
_impl_discardAlarm (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_createObject(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_createObject)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev)) {
_impl_createObject (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_modifyObject(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_modifyObject)(PortableServer_Servant _servant, const CORBA_char * calobj, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev)) {
_impl_modifyObject (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_long *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_removeObject(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_removeObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev)) {
_impl_removeObject (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_char * *)_o_args[1], *(const CORBA_long *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getAttachmentList(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getAttachmentList)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev)) {
_impl_getAttachmentList (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_receiveObjects(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_receiveObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev)) {
_impl_receiveObjects (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_sendObjects(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_sendObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev)) {
_impl_sendObjects (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getQuery(POA_GNOME_Evolution_Calendar_Cal             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_getQuery)(PortableServer_Servant _servant, const CORBA_char * sexp, const GNOME_Evolution_Calendar_CalViewListener ql, CORBA_Environment *ev)) {
_impl_getQuery (_o_servant, *(const CORBA_char * *)_o_args[0], *(const GNOME_Evolution_Calendar_CalViewListener *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyReadOnly(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyReadOnly)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_boolean read_only, CORBA_Environment *ev)) {
_impl_notifyReadOnly (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_boolean *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalAddress(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyCalAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev)) {
_impl_notifyCalAddress (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyAlarmEmailAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev)) {
_impl_notifyAlarmEmailAddress (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyLDAPAttribute)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * ldap_attribute, CORBA_Environment *ev)) {
_impl_notifyLDAPAttribute (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyStaticCapabilities)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * capabilities, CORBA_Environment *ev)) {
_impl_notifyStaticCapabilities (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalOpened(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyCalOpened)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyCalOpened (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalRemoved(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyCalRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyCalRemoved (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectCreated(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectCreated)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * uid, CORBA_Environment *ev)) {
_impl_notifyObjectCreated (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectModified(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyObjectModified (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyObjectRemoved (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyAlarmDiscarded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyAlarmDiscarded (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectsReceived)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyObjectsReceived (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectsSent(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectsSent)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_UserList* users, const CORBA_char * calobj, CORBA_Environment *ev)) {
_impl_notifyObjectsSent (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], (const CORBA_sequence_GNOME_Evolution_Calendar_User*)_o_args[1], *(const CORBA_char * *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyDefaultObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev)) {
_impl_notifyDefaultObjectRequested (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectRequested(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev)) {
_impl_notifyObjectRequested (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyObjectListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev)) {
_impl_notifyObjectListRequested (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], (const CORBA_sequence_CORBA_string*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyQuery(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyQuery)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalView query, CORBA_Environment *ev)) {
_impl_notifyQuery (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const GNOME_Evolution_Calendar_CalView *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyTimezoneRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tz, CORBA_Environment *ev)) {
_impl_notifyTimezoneRequested (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyTimezoneAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tzid, CORBA_Environment *ev)) {
_impl_notifyTimezoneAdded (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], *(const CORBA_char * *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyDefaultTimezoneSet)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev)) {
_impl_notifyDefaultTimezoneSet (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyChanges(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyChanges)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjChangeSeq* changes, CORBA_Environment *ev)) {
_impl_notifyChanges (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], (const CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyFreeBusy(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjSeq* freebusy, CORBA_Environment *ev)) {
_impl_notifyFreeBusy (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], (const CORBA_sequence_GNOME_Evolution_Calendar_CalObj*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyAttachmentListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* attachments, CORBA_Environment *ev)) {
_impl_notifyAttachmentListRequested (_o_servant, *(const GNOME_Evolution_Calendar_CallStatus *)_o_args[0], (const CORBA_sequence_CORBA_string*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalSetMode(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyCalSetMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalListener_SetModeStatus status, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev)) {
_impl_notifyCalSetMode (_o_servant, *(const GNOME_Evolution_Calendar_CalListener_SetModeStatus *)_o_args[0], *(const CORBA_long *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyErrorOccurred)(PortableServer_Servant _servant, const CORBA_char * message, CORBA_Environment *ev)) {
_impl_notifyErrorOccurred (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAuthRequired(POA_GNOME_Evolution_Calendar_CalListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_notifyAuthRequired)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_notifyAuthRequired (_o_servant, _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalFactory_getCal(POA_GNOME_Evolution_Calendar_CalFactory             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
GNOME_Evolution_Calendar_Cal (*_impl_getCal)(PortableServer_Servant _servant, const CORBA_char * source, const GNOME_Evolution_Calendar_CalObjType type, const GNOME_Evolution_Calendar_CalListener listener, CORBA_Environment *ev)) {
*(GNOME_Evolution_Calendar_Cal *)_o_retval = _impl_getCal (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_long *)_o_args[1], *(const GNOME_Evolution_Calendar_CalListener *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CompEditorFactory_editExisting(POA_GNOME_Evolution_Calendar_CompEditorFactory             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_editExisting)(PortableServer_Servant _servant, const CORBA_char * uri, const CORBA_char * uid, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev)) {
_impl_editExisting (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_char * *)_o_args[1], *(const CORBA_long *)_o_args[2], _o_ev);
}
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CompEditorFactory_editNew(POA_GNOME_Evolution_Calendar_CompEditorFactory             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_editNew)(PortableServer_Servant _servant, const CORBA_char * uri, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev)) {
_impl_editNew (_o_servant, *(const CORBA_char * *)_o_args[0], *(const CORBA_long *)_o_args[1], _o_ev);
}

#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObj)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObj 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array5[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObj_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array5,
CORBA_OBJECT_NIL,
(char *)"CalObj",
(char *)"IDL:GNOME/Evolution/Calendar/CalObj:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array8[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array8,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array11[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObj_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array11,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array18[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObj_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array18,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array21[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array21,
CORBA_OBJECT_NIL,
(char *)"CalObjSeq",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array24[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array24,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array31[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array31,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_stringlist)
#define TC_DEF_TC_GNOME_Evolution_Calendar_stringlist 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array34[] = {(CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_stringlist_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array34,
CORBA_OBJECT_NIL,
(char *)"stringlist",
(char *)"IDL:GNOME/Evolution/Calendar/stringlist:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjUID)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjUID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array41[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjUID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array41,
CORBA_OBJECT_NIL,
(char *)"CalObjUID",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjUID:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalRecurID)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalRecurID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array48[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalRecurID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array48,
CORBA_OBJECT_NIL,
(char *)"CalRecurID",
(char *)"IDL:GNOME/Evolution/Calendar/CalRecurID:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array51[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array51,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array58[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array58,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_StringSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_StringSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array61[] = {(CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_StringSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array61,
CORBA_OBJECT_NIL,
(char *)"StringSeq",
(char *)"IDL:GNOME/Evolution/Calendar/StringSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array64[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array64,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array67[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array67,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array74[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array74,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjUIDSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjUIDSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array77[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjUIDSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array77,
CORBA_OBJECT_NIL,
(char *)"CalObjUIDSeq",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjUIDSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjID)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjID 1
static const char *anon_subnames_array79[] = {"uid", "rid"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array80[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUID_struct, (CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalRecurID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array80,
CORBA_OBJECT_NIL,
(char *)"CalObjID",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjID:1.0",
(char **)anon_subnames_array79,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array83[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array83,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array90[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array90,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjIDSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjIDSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array93[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjIDSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array93,
CORBA_OBJECT_NIL,
(char *)"CalObjIDSeq",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjIDSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalTimezoneObj)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalTimezoneObj 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array100[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalTimezoneObj_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array100,
CORBA_OBJECT_NIL,
(char *)"CalTimezoneObj",
(char *)"IDL:GNOME/Evolution/Calendar/CalTimezoneObj:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array107[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array107,
CORBA_OBJECT_NIL,
(char *)"CalTimezoneObjUID",
(char *)"IDL:GNOME/Evolution/Calendar/CalTimezoneObjUID:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalAlarmUID)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalAlarmUID 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array114[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalAlarmUID_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array114,
CORBA_OBJECT_NIL,
(char *)"CalAlarmUID",
(char *)"IDL:GNOME/Evolution/Calendar/CalAlarmUID:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjType)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjType 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array121[] = {(CORBA_TypeCode)&TC_CORBA_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array121,
CORBA_OBJECT_NIL,
(char *)"CalObjType",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjType:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjModType)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjModType 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array128[] = {(CORBA_TypeCode)&TC_CORBA_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjModType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array128,
CORBA_OBJECT_NIL,
(char *)"CalObjModType",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjModType:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalMode)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalMode 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array135[] = {(CORBA_TypeCode)&TC_CORBA_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalMode_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array135,
CORBA_OBJECT_NIL,
(char *)"CalMode",
(char *)"IDL:GNOME/Evolution/Calendar/CalMode:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChangeType)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChangeType 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array142[] = {(CORBA_TypeCode)&TC_CORBA_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChangeType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array142,
CORBA_OBJECT_NIL,
(char *)"CalObjChangeType",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjChangeType:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_Time_t)
#define TC_DEF_TC_GNOME_Evolution_Calendar_Time_t 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array149[] = {(CORBA_TypeCode)&TC_CORBA_unsigned_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Time_t_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array149,
CORBA_OBJECT_NIL,
(char *)"Time_t",
(char *)"IDL:GNOME/Evolution/Calendar/Time_t:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjInstance)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjInstance 1
static const char *anon_subnames_array151[] = {"uid", "start", "end"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array152[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUID_struct, (CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Time_t_struct, (CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Time_t_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjInstance_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_POINTER, 1)),
0,
3
,
(CORBA_TypeCode *)anon_subtypes_array152,
CORBA_OBJECT_NIL,
(char *)"CalObjInstance",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjInstance:1.0",
(char **)anon_subnames_array151,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array155[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjInstance_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array155,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array162[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjInstance_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array162,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array165[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array165,
CORBA_OBJECT_NIL,
(char *)"CalObjInstanceSeq",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjInstanceSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChange)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChange 1
static const char *anon_subnames_array167[] = {"calobj", "type"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array168[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObj_struct, (CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChangeType_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_POINTER, 1)),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array168,
CORBA_OBJECT_NIL,
(char *)"CalObjChange",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjChange:1.0",
(char **)anon_subnames_array167,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array171[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array171,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array178[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array178,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChangeSeq)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalObjChangeSeq 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array181[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChangeSeq_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array181,
CORBA_OBJECT_NIL,
(char *)"CalObjChangeSeq",
(char *)"IDL:GNOME/Evolution/Calendar/CalObjChangeSeq:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_User_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_User_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_User)
#define TC_DEF_TC_GNOME_Evolution_Calendar_User 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array188[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_User_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array188,
CORBA_OBJECT_NIL,
(char *)"User",
(char *)"IDL:GNOME/Evolution/Calendar/User:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array191[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array191,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_User)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_User 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array194[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_User_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_User_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array194,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_0 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_10 == 'c') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_12 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_13 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_14 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_15 == 'd') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_16 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_17 == 'r') \
) && !defined(TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_User)
#define TC_DEF_TC_CORBA_sequence_GNOME_Evolution_Calendar_User 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array201[] = {(CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_User_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_User_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array201,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_UserList)
#define TC_DEF_TC_GNOME_Evolution_Calendar_UserList 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array204[] = {(CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_User_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_UserList_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array204,
CORBA_OBJECT_NIL,
(char *)"UserList",
(char *)"IDL:GNOME/Evolution/Calendar/UserList:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CallStatus)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CallStatus 1
static const char *anon_subnames_array206[] = {"Success", "RepositoryOffline", "PermissionDenied", "InvalidRange", "ObjectNotFound", "InvalidObject", "ObjectIdAlreadyExists", "AuthenticationFailed", "AuthenticationRequired", "UnsupportedField", "UnsupportedMethod", "UnsupportedAuthenticationMethod", "TLSNotAvailable", "NoSuchCal", "UnknownUser", "OfflineUnavailable", "SearchSizeLimitExceeded", "SearchTimeLimitExceeded", "InvalidQuery", "QueryRefused", "CouldNotCancel", "OtherError", "InvalidServerVersion"};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CallStatus_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_enum,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
23
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CallStatus",
(char *)"IDL:GNOME/Evolution/Calendar/CallStatus:1.0",
(char **)anon_subnames_array206,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalView)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalView 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalView_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CalView",
(char *)"IDL:GNOME/Evolution/Calendar/CalView:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalViewListener)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalViewListener 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalViewListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CalViewListener",
(char *)"IDL:GNOME/Evolution/Calendar/CalViewListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_Cal_NotFound)
#define TC_DEF_TC_GNOME_Evolution_Calendar_Cal_NotFound 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_NotFound_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"NotFound",
(char *)"IDL:GNOME/Evolution/Calendar/Cal/NotFound:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_Cal_InvalidRange)
#define TC_DEF_TC_GNOME_Evolution_Calendar_Cal_InvalidRange 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_InvalidRange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"InvalidRange",
(char *)"IDL:GNOME/Evolution/Calendar/Cal/InvalidRange:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_Cal)
#define TC_DEF_TC_GNOME_Evolution_Calendar_Cal 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"Cal",
(char *)"IDL:GNOME/Evolution/Calendar/Cal:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus 1
static const char *anon_subnames_array224[] = {"MODE_SET", "MODE_NOT_SET", "MODE_NOT_SUPPORTED"};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_enum,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
3
,
NULL,
CORBA_OBJECT_NIL,
(char *)"SetModeStatus",
(char *)"IDL:GNOME/Evolution/Calendar/CalListener/SetModeStatus:1.0",
(char **)anon_subnames_array224,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalListener)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalListener 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CalListener",
(char *)"IDL:GNOME/Evolution/Calendar/CalListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_NilListener)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_NilListener 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_NilListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"NilListener",
(char *)"IDL:GNOME/Evolution/Calendar/CalFactory/NilListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"InvalidURI",
(char *)"IDL:GNOME/Evolution/Calendar/CalFactory/InvalidURI:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"UnsupportedMethod",
(char *)"IDL:GNOME/Evolution/Calendar/CalFactory/UnsupportedMethod:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CalFactory 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CalFactory",
(char *)"IDL:GNOME/Evolution/Calendar/CalFactory:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"InvalidURI",
(char *)"IDL:GNOME/Evolution/Calendar/CompEditorFactory/InvalidURI:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"BackendContactError",
(char *)"IDL:GNOME/Evolution/Calendar/CompEditorFactory/BackendContactError:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
1,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"UnsupportedType",
(char *)"IDL:GNOME/Evolution/Calendar/CompEditorFactory/UnsupportedType:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array256[] = {(CORBA_TypeCode)&TC_CORBA_long_struct};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array256,
CORBA_OBJECT_NIL,
(char *)"CompEditorMode",
(char *)"IDL:GNOME/Evolution/Calendar/CompEditorFactory/CompEditorMode:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory)
#define TC_DEF_TC_GNOME_Evolution_Calendar_CompEditorFactory 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"CompEditorFactory",
(char *)"IDL:GNOME/Evolution/Calendar/CompEditorFactory:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_0 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_1 == 'v') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_2 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_3 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_4 == 'u') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_5 == 't') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_6 == 'i') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_7 == 'o') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_8 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_9 == '_') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_10 == 'c') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_11 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_12 == 'l') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_13 == 'e') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_14 == 'n') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_15 == 'd') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_16 == 'a') \
&& (TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_17 == 'r') \
) && !defined(TC_DEF_TC_GNOME_Evolution_Calendar_AlarmNotify)
#define TC_DEF_TC_GNOME_Evolution_Calendar_AlarmNotify 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_AlarmNotify_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
(char *)"AlarmNotify",
(char *)"IDL:GNOME/Evolution/Calendar/AlarmNotify:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_CalView__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_CalViewListener__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_Cal__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_CalListener__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_CalFactory__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_CompEditorFactory__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_evolution_calendar
CORBA_unsigned_long GNOME_Evolution_Calendar_AlarmNotify__classid = 0;
#endif

/* Interface type data */


#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalView__imethods [] = {
	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"start", 5,
		0 | ORBit_I_METHOD_1_WAY
}
};

static CORBA_string GNOME_Evolution_Calendar_CalView__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalView__iinterface = {
TC_GNOME_Evolution_Calendar_CalView,{1, 1, GNOME_Evolution_Calendar_CalView__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_CalView__base_itypes, FALSE}
};

static ORBit_IArg GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_stringlist,  ORBit_I_ARG_IN , (char *)"objects" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_stringlist,  ORBit_I_ARG_IN , (char *)"objects" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObjIDSeq,  ORBit_I_ARG_IN , (char *)"ids" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"message" },
	{ TC_CORBA_short,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"percent" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalViewListener__imethods [] = {
	{
		{ 1, 1, GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectsAdded", 18,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectsModified", 21,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectsRemoved", 20,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyQueryProgress", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyQueryDone", 15,
		0 | ORBit_I_METHOD_1_WAY
}
};

static CORBA_string GNOME_Evolution_Calendar_CalViewListener__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalViewListener__iinterface = {
TC_GNOME_Evolution_Calendar_CalViewListener,{5, 5, GNOME_Evolution_Calendar_CalViewListener__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_CalViewListener__base_itypes, FALSE}
};

static ORBit_IArg GNOME_Evolution_Calendar_Cal_open__arginfo [] = {
	{ TC_CORBA_boolean,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"only_if_exists" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"username" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"password" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_setMode__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalMode,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mode" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getObject__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObjUID,  ORBit_I_ARG_IN , (char *)"uid" },
	{ TC_GNOME_Evolution_Calendar_CalRecurID,  ORBit_I_ARG_IN , (char *)"rid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getObjectList__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"query" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getTimezone__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalTimezoneObjUID,  ORBit_I_ARG_IN , (char *)"tzid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_addTimezone__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalTimezoneObj,  ORBit_I_ARG_IN , (char *)"tz" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_setDefaultTimezone__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalTimezoneObj,  ORBit_I_ARG_IN , (char *)"tz" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getChanges__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"change_id" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getFreeBusy__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_UserList,  ORBit_I_ARG_IN , (char *)"users" },
	{ TC_GNOME_Evolution_Calendar_Time_t,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"start" },
	{ TC_GNOME_Evolution_Calendar_Time_t,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"end" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_discardAlarm__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObjUID,  ORBit_I_ARG_IN , (char *)"uid" },
	{ TC_GNOME_Evolution_Calendar_CalAlarmUID,  ORBit_I_ARG_IN , (char *)"auid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_createObject__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"calobj" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_modifyObject__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"calobj" },
	{ TC_GNOME_Evolution_Calendar_CalObjModType,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mod" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_removeObject__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObjUID,  ORBit_I_ARG_IN , (char *)"uid" },
	{ TC_GNOME_Evolution_Calendar_CalRecurID,  ORBit_I_ARG_IN , (char *)"rid" },
	{ TC_GNOME_Evolution_Calendar_CalObjModType,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mod" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getAttachmentList__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObjUID,  ORBit_I_ARG_IN , (char *)"uid" },
	{ TC_GNOME_Evolution_Calendar_CalRecurID,  ORBit_I_ARG_IN , (char *)"rid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_receiveObjects__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"calobj" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_sendObjects__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"calobj" }
};
static ORBit_IArg GNOME_Evolution_Calendar_Cal_getQuery__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"sexp" },
	{ TC_GNOME_Evolution_Calendar_CalViewListener,  ORBit_I_ARG_IN , (char *)"ql" }
};

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_Cal__imethods [] = {
	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		TC_CORBA_string, (char *)"_get_uri", 8,
		0
}
, 	{
		{ 3, 3, GNOME_Evolution_Calendar_Cal_open__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"open", 4,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"remove", 6,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"isReadOnly", 10,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getStaticCapabilities", 21,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getCalAddress", 13,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getAlarmEmailAddress", 20,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getLdapAttribute", 16,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_setMode__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"setMode", 7,
		0
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getDefaultObject", 16,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_Cal_getObject__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getObject", 9,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_getObjectList__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getObjectList", 13,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_getTimezone__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getTimezone", 11,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_addTimezone__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"addTimezone", 11,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_setDefaultTimezone__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"setDefaultTimezone", 18,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_getChanges__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getChanges", 10,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 3, 3, GNOME_Evolution_Calendar_Cal_getFreeBusy__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getFreeBusy", 11,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_Cal_discardAlarm__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"discardAlarm", 12,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_createObject__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"createObject", 12,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_Cal_modifyObject__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"modifyObject", 12,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 3, 3, GNOME_Evolution_Calendar_Cal_removeObject__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"removeObject", 12,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_Cal_getAttachmentList__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getAttachmentList", 17,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_receiveObjects__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"receiveObjects", 14,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_Cal_sendObjects__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"sendObjects", 11,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_Cal_getQuery__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"getQuery", 8,
		0 | ORBit_I_METHOD_1_WAY
}
};

static CORBA_string GNOME_Evolution_Calendar_Cal__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_Cal__iinterface = {
TC_GNOME_Evolution_Calendar_Cal,{25, 25, GNOME_Evolution_Calendar_Cal__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_Cal__base_itypes, FALSE}
};

static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyReadOnly__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_boolean,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"read_only" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyCalAddress__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"address" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"address" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"ldap_attribute" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"capabilities" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyCalOpened__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyCalRemoved__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectCreated__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"uid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectModified__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectsSent__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_UserList,  ORBit_I_ARG_IN , (char *)"users" },
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"calobj" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"object" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectRequested__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalObj,  ORBit_I_ARG_IN , (char *)"object" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_stringlist,  ORBit_I_ARG_IN , (char *)"objects" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyQuery__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalView,  ORBit_I_ARG_IN , (char *)"query" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalTimezoneObj,  ORBit_I_ARG_IN , (char *)"tz" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalTimezoneObjUID,  ORBit_I_ARG_IN , (char *)"tzid" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyChanges__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalObjChangeSeq,  ORBit_I_ARG_IN , (char *)"changes" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyFreeBusy__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalObjSeq,  ORBit_I_ARG_IN , (char *)"freebusy" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CallStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_stringlist,  ORBit_I_ARG_IN , (char *)"attachments" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyCalSetMode__arginfo [] = {
	{ TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"status" },
	{ TC_GNOME_Evolution_Calendar_CalMode,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mode" }
};
static ORBit_IArg GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"message" }
};

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalListener__imethods [] = {
	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyReadOnly__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyReadOnly", 14,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyCalAddress__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyCalAddress", 16,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyAlarmEmailAddress", 23,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyLDAPAttribute", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyStaticCapabilities", 24,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyCalOpened__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyCalOpened", 15,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyCalRemoved__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyCalRemoved", 16,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyObjectCreated__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectCreated", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyObjectModified__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectModified", 20,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectRemoved", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyAlarmDiscarded", 20,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectsReceived", 21,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 3, 3, GNOME_Evolution_Calendar_CalListener_notifyObjectsSent__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectsSent", 17,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyDefaultObjectRequested", 28,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyObjectRequested__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectRequested", 21,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyObjectListRequested", 25,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyQuery__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyQuery", 11,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyTimezoneRequested", 23,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyTimezoneAdded", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyDefaultTimezoneSet", 24,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyChanges__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyChanges", 13,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyFreeBusy__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyFreeBusy", 14,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyAttachmentListRequested", 29,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CalListener_notifyCalSetMode__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyCalSetMode", 16,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyErrorOccurred", 19,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, (char *)"notifyAuthRequired", 18,
		0 | ORBit_I_METHOD_1_WAY
}
};

static CORBA_string GNOME_Evolution_Calendar_CalListener__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalListener__iinterface = {
TC_GNOME_Evolution_Calendar_CalListener,{26, 26, GNOME_Evolution_Calendar_CalListener__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_CalListener__base_itypes, FALSE}
};

static ORBit_IArg GNOME_Evolution_Calendar_CalFactory_getCal__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"source" },
	{ TC_GNOME_Evolution_Calendar_CalObjType,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"type" },
	{ TC_GNOME_Evolution_Calendar_CalListener,  ORBit_I_ARG_IN , (char *)"listener" }
};
/* Exceptions */
static CORBA_TypeCode GNOME_Evolution_Calendar_CalFactory_getCal__exceptinfo [] = {
	TC_GNOME_Evolution_Calendar_CalFactory_NilListener,
	TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI,
	TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalFactory__imethods [] = {
	{
		{ 3, 3, GNOME_Evolution_Calendar_CalFactory_getCal__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 3, 3, GNOME_Evolution_Calendar_CalFactory_getCal__exceptinfo, FALSE },
		TC_GNOME_Evolution_Calendar_Cal, (char *)"getCal", 6,
		0
}
};

static CORBA_string GNOME_Evolution_Calendar_CalFactory__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalFactory__iinterface = {
TC_GNOME_Evolution_Calendar_CalFactory,{1, 1, GNOME_Evolution_Calendar_CalFactory__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_CalFactory__base_itypes, FALSE}
};

static ORBit_IArg GNOME_Evolution_Calendar_CompEditorFactory_editExisting__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"uri" },
	{ TC_GNOME_Evolution_Calendar_CalObjUID,  ORBit_I_ARG_IN , (char *)"uid" },
	{ TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mode" }
};
/* Exceptions */
static CORBA_TypeCode GNOME_Evolution_Calendar_CompEditorFactory_editExisting__exceptinfo [] = {
	TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI,
	TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError,
	NULL
};
static ORBit_IArg GNOME_Evolution_Calendar_CompEditorFactory_editNew__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , (char *)"uri" },
	{ TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, (char *)"mode" }
};
/* Exceptions */
static CORBA_TypeCode GNOME_Evolution_Calendar_CompEditorFactory_editNew__exceptinfo [] = {
	TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI,
	TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError,
	TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CompEditorFactory__imethods [] = {
	{
		{ 3, 3, GNOME_Evolution_Calendar_CompEditorFactory_editExisting__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 2, 2, GNOME_Evolution_Calendar_CompEditorFactory_editExisting__exceptinfo, FALSE },
TC_void, (char *)"editExisting", 12,
		0
}
, 	{
		{ 2, 2, GNOME_Evolution_Calendar_CompEditorFactory_editNew__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 3, 3, GNOME_Evolution_Calendar_CompEditorFactory_editNew__exceptinfo, FALSE },
TC_void, (char *)"editNew", 7,
		0
}
};

static CORBA_string GNOME_Evolution_Calendar_CompEditorFactory__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CompEditorFactory__iinterface = {
TC_GNOME_Evolution_Calendar_CompEditorFactory,{2, 2, GNOME_Evolution_Calendar_CompEditorFactory__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_CompEditorFactory__base_itypes, FALSE}
};

static CORBA_string GNOME_Evolution_Calendar_AlarmNotify__base_itypes[] = {
(char *)"IDL:Bonobo/Unknown:1.0",
(char *)"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#endif
ORBit_IInterface GNOME_Evolution_Calendar_AlarmNotify__iinterface = {
TC_GNOME_Evolution_Calendar_AlarmNotify,{0, 0, GNOME_Evolution_Calendar_AlarmNotify__imethods, FALSE},
{2, 2, GNOME_Evolution_Calendar_AlarmNotify__base_itypes, FALSE}
};

